==> dhall-docs-1.0.12-160-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-docs
version:              1.0.12
visibility:           public
id:                   dhall-docs-1.0.12-FSqiphGXqz2UqNOEPR62
key:                  dhall-docs-1.0.12-FSqiphGXqz2UqNOEPR62
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  3ea182a53a89c1570f52c497a94f4e26
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.12-FSqiphGXqz2UqNOEPR62
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-4oSM5otI4Ra8wFWOp2kkt3
    dhall-1.42.3-6ivmxcjn5ctBDS3CQUifdU directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    lucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
    mmark-0.0.7.6-I3gmhliLEjIA9qAJLEObvW mtl-2.3.1
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    path-0.9.6-JZJSfxZgLNX9Y539GdP67P
    path-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-docs-1.0.12-163-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-docs
version:              1.0.12
visibility:           public
id:                   dhall-docs-1.0.12-Hh8zcxLOMMcFImoj0Kv0VP
key:                  dhall-docs-1.0.12-Hh8zcxLOMMcFImoj0Kv0VP
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  7ced45398f53daf01a01593b8c1fd1d8
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.12-Hh8zcxLOMMcFImoj0Kv0VP
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-6gPusxqn90AJxFEjBUebK6
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-8XHw5QTKQKOLRqWL48SiFE
    dhall-1.42.3-EidAGmin8lt7mPY3yHO1CI directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    lucid-2.11.20250303-K6g6EvbE7Ue4YCDhz9bqif
    megaparsec-9.7.0-EBrXuyfSuyTIUi7T8Ua8UQ
    mmark-0.0.7.6-Jj8sAQgVptuEb28tvSoiNA mtl-2.3.1
    optparse-applicative-0.18.1.0-EZi3UgmTFLmKW119EQEIXK
    path-0.9.6-BfPc0tTnWDFIco9YzxzKzp
    path-io-1.8.2-jT5LkidbSC8X8P7dmIqx8
    prettyprinter-1.7.1-LgLGkLn2CvpBXnv6jAGI5w text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
